@@ -75,14 +75,8 @@ import zipfile
 from operator import attrgetter
 from compiler.visitor import ASTVisitor
 
-try:
-    set
-except NameError:
-    # Python 2.4 compatibility
-    from sets import Set as set
 
-
-__version__ = '1.2.10'
+__version__ = '1.2.11'
 
 
 def adjust_lineno(filename, lineno, name):
@@ -368,13 +362,17 @@ class ModuleGraph(object):
     verbose = False
     external_dependencies = True
 
+    # some builtin modules do not exist as separate .so files on disk
+    builtin_modules = (
+        'gc',
+        'cPickle', # since Python 2.6 there's no cPickle.so any more
+    )
+
     def __init__(self):
         self.modules = {}
         self.path = sys.path
         self._module_cache = {}
-        # some builtin modules cannot be found using normal means, but we don't
-        # want to report warnings about them
-        self._warned_about = set(['gc'])
+        self._warned_about = set()
 
     def parsePathname(self, pathname):
         """Parse one or more source files.
@@ -432,7 +430,6 @@ class ModuleGraph(object):
                 break
         else:
             print >> sys.stderr, "%s: unknown file name extension" % filename
-        longest_prefix_len = 0
         filename = os.path.abspath(filename)
         elements = filename.split(os.path.sep)
         modname = []
@@ -470,7 +467,7 @@ class ModuleGraph(object):
             return self._module_cache[(dotted_name, extrapath)]
         except KeyError:
             pass
-        if dotted_name in sys.modules:
+        if dotted_name in sys.modules or dotted_name in self.builtin_modules:
             return dotted_name
         filename = dotted_name.replace('.', os.path.sep)
         if extrapath:
